==> activity-common-api-1.3.40-sources.jar: cn/com/duiba/activity/common/center/api/params/AppConsumerCashDrawsRecordParam.java <==
package cn.com.duiba.activity.common.center.api.params;

import cn.com.duiba.activity.common.center.api.enums.consumeraccounts.AccountCashDrawStatusEnum;
import cn.com.duiba.activity.common.center.api.enums.consumeraccounts.AccountTypeEnum;

import java.util.Date;
import java.util.List;

/**
 * Created by HePeng on 2018/10/30 15:52.
 */
public class AppConsumerCashDrawsRecordParam extends PageParams {
    private static final long serialVersionUID = -7077577582840936260L;
    /**
     * 记录id，可选
     */
    private Long id;
    /**
     * 应用id，必须
     */
    private Long appId;
    /**
     * 账户类型，必须
     */
    private AccountTypeEnum accountTypeEnum;
    /**
     * 提现状态，可选
     */
    private List<AccountCashDrawStatusEnum> accountCashDrawStatusEnumList;
    /**
     * 起始时间（创建时间大于等于），必须
     */
    private Date start;
    /**
     * 结束时间（创建时间小于），必须
     */
    private Date end;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public AccountTypeEnum getAccountTypeEnum() {
        return accountTypeEnum;
    }

    public void setAccountTypeEnum(AccountTypeEnum accountTypeEnum) {
        this.accountTypeEnum = accountTypeEnum;
    }

    public List<AccountCashDrawStatusEnum> getAccountCashDrawStatusEnumList() {
        return accountCashDrawStatusEnumList;
    }

    public void setAccountCashDrawStatusEnumList(List<AccountCashDrawStatusEnum> accountCashDrawStatusEnumList) {
        this.accountCashDrawStatusEnumList = accountCashDrawStatusEnumList;
    }

    public Date getStart() {
        return start;
    }

    public void setStart(Date start) {
        this.start = start;
    }

    public Date getEnd() {
        return end;
    }

    public void setEnd(Date end) {
        this.end = end;
    }
}

==> activity-common-api-1.4.31-sources.jar: cn/com/duiba/activity/common/center/api/params/AppConsumerCashDrawsRecordParam.java <==
package cn.com.duiba.activity.common.center.api.params;

import cn.com.duiba.activity.common.center.api.enums.consumeraccounts.AccountCashDrawStatusEnum;
import cn.com.duiba.activity.common.center.api.enums.consumeraccounts.AccountTypeEnum;

import java.util.Date;
import java.util.List;

/**
 * Created by HePeng on 2018/10/30 15:52.
 */
public class AppConsumerCashDrawsRecordParam extends PageParams {
    private static final long serialVersionUID = -7077577582840936260L;
    /**
     * 记录id，可选
     */
    private Long id;
    /**
     * 应用id，必须
     */
    private Long appId;
    /**
     * 账户类型，必须
     */
    private AccountTypeEnum accountTypeEnum;
    /**
     * 提现状态，可选
     */
    private List<AccountCashDrawStatusEnum> accountCashDrawStatusEnumList;
    /**
     * 起始时间（创建时间大于等于），必须
     */
    private Date start;
    /**
     * 结束时间（创建时间小于），必须
     */
    private Date end;

    private String account;

    private Long consumerId;

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public AccountTypeEnum getAccountTypeEnum() {
        return accountTypeEnum;
    }

    public void setAccountTypeEnum(AccountTypeEnum accountTypeEnum) {
        this.accountTypeEnum = accountTypeEnum;
    }

    public List<AccountCashDrawStatusEnum> getAccountCashDrawStatusEnumList() {
        return accountCashDrawStatusEnumList;
    }

    public void setAccountCashDrawStatusEnumList(List<AccountCashDrawStatusEnum> accountCashDrawStatusEnumList) {
        this.accountCashDrawStatusEnumList = accountCashDrawStatusEnumList;
    }

    public Date getStart() {
        return start;
    }

    public void setStart(Date start) {
        this.start = start;
    }

    public Date getEnd() {
        return end;
    }

    public void setEnd(Date end) {
        this.end = end;
    }
}
